pub fn block_decode(
raw_block_hex: &str,
network: Network,
txids_only: bool,
) -> Result<BlockDecodeOutput, BlockError>Expand description
Decode a raw block and return block info or header info.
pub fn block_decode(
raw_block_hex: &str,
network: Network,
txids_only: bool,
) -> Result<BlockDecodeOutput, BlockError>Decode a raw block and return block info or header info.