Module pset

Module pset 

Structs

JetCall
RunResponse
UpdatedPset

Enums

PsetCreateError
PsetError
PsetExtractError
PsetFinalizeError
PsetRunError
PsetUpdateInputError

Functions

execution_environment
Helper function to create execution environment for PSET operations
pset_create
Create an empty PSET
pset_extract
Extract a raw transaction from a completed PSET
pset_finalize
Attach a Simplicity program and witness to a PSET input
pset_run
Run a Simplicity program in the context of a PSET input
pset_update_input
Attach UTXO data to a PSET input