Structs
Enums
Functions
- execution_
environment - Helper function to create execution environment for PSET operations
- pset_
create - Create an empty PSET
- pset_
extract - Extract a raw transaction from a completed PSET
- pset_
finalize - Attach a Simplicity program and witness to a PSET input
- pset_
run - Run a Simplicity program in the context of a PSET input
- pset_
update_ input - Attach UTXO data to a PSET input